"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.assertUserOptions = void 0;
const tslib_1 = require("tslib");
const assert_1 = tslib_1.__importDefault(require("assert"));
function assertIsPage(maybePage, prefix) {
    if (typeof maybePage.mainFrame !== 'function') {
        const message = prefix + 'not a valid page! Method page.mainFrame() not found.';
        throw new assert_1.default.AssertionError({ message });
    }
}
function assertIsOptionalBoolean(val, message) {
    if (typeof val !== 'undefined' && typeof val !== 'boolean') {
        throw new assert_1.default.AssertionError({ message });
    }
}
function assertIsOptionalString(val, message) {
    if (typeof val !== 'undefined' && typeof val !== 'string') {
        throw new assert_1.default.AssertionError({ message });
    }
}
function assertIsStringOrStringArray(val, prefix) {
    const isString = typeof val === 'string';
    const isStringArray = Array.isArray(val) && val.every(item => typeof item === 'string');
    if (!isString && !isStringArray) {
        const message = prefix + 'not a string or string[]';
        throw new assert_1.default.AssertionError({ message });
    }
}
function assertIsUserInterceptor(val, prefix) {
    assertIsOptionalString(val.name, prefix + 'interceptor.name must be a string');
    assertIsOptionalString(val.url, prefix + 'interceptor.url must be a string');
    assertIsOptionalBoolean(val.pass, prefix + 'interceptor.pass must be boolean');
    assertIsOptionalString(val.name, prefix + 'interceptor.name must be a string');
    assertIsOptionalString(val.name, prefix + 'interceptor.name must be a string');
    if (typeof val.name !== 'undefined' && typeof val.name !== 'string') {
        const message = prefix + 'interceptor.name must be a string';
        throw new assert_1.default.AssertionError({ message });
    }
    if (typeof val.url !== 'undefined' && typeof val.url !== 'string') {
        const message = prefix + 'interceptor.url must be a string';
        throw new assert_1.default.AssertionError({ message });
    }
    if (typeof val.url !== 'undefined' && typeof val.url !== 'string') {
        const message = prefix + 'interceptor.url must be a string';
        throw new assert_1.default.AssertionError({ message });
    }
}
function assertUserOptions(userOptions, msg = 'teremock.start() options validation: ') {
    if (typeof userOptions.page !== 'undefined') {
        assertIsPage(userOptions.page, msg);
    }
    if (typeof userOptions.wd !== 'undefined') {
        assertIsStringOrStringArray(userOptions.wd, msg);
    }
    if (typeof userOptions.interceptors !== 'undefined') {
        Object.keys(userOptions.interceptors).forEach(key => {
            return assertIsUserInterceptor(userOptions.interceptors[key], msg + key + ' ');
        });
    }
}
exports.assertUserOptions = assertUserOptions;
